@@ -48,7 +48,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "15.0",
+    VERSIONNUM       => "15.1",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -111,7 +111,8 @@ sub pacemaker_online{
     # Pacemaker が Online だったら1を返却する
     foreach my $line (@crm_results){
         # pcs status --full の結果に「Online: [ ～ <マシンのホスト名>」の行が存在すると OK
-        if ($line =~ /Online\:\s+\[(\s+\S+)?\s.*$my_node\s+/){
+        if ($line =~ /Online\:\s+\[(\s+\S+)?\s.*$my_node\s+/
+            || $line =~ /Node $my_node .*: online,/){
             return 1;
         }
     }
